agentle.agents.ui.streamlit
===========================

.. automodule:: agentle.agents.ui.streamlit

   
   .. rubric:: Functions

   .. autosummary::
   
      cast
   
   .. rubric:: Classes

   .. autosummary::
   
      Adapter
      Agent
      AgentToStreamlit
      Any
      Callable
      FilePart
      StaticKnowledge
      TextPart
      ToolExecutionSuggestion
      UserMessage
   